@@ -1,7 +1,7 @@
 import os
 from collections import OrderedDict
 
-__VERSION__ = "1.10.0"
+__VERSION__ = "1.11.0"
 __version__ = __VERSION__
 
 ASSAY_LIST = [
@@ -16,15 +16,14 @@ ASSAY_LIST = [
     'capture_rna',
     'citeseq',
     'sweetseq',
-    'fl_vdj_CR',
+    'flv_CR',
     'convert10X',
-    'fl_vdj_TRUST4',
-    'fl_vdj_TRUST4_split',
+    'flv_trust4',
 ]
 
 ROOT_PATH = os.path.dirname(__file__)
 
-RELEASED_ASSAYS = ['rna', 'vdj', 'tag', 'dynaseq', 'snp', 'capture_virus']
+RELEASED_ASSAYS = ['rna', 'vdj', 'tag', 'dynaseq', 'snp', 'capture_virus', 'fusion', 'flv_CR', 'flv_trust4']
 
 # argument help
 HELP_DICT = {
@@ -43,7 +42,10 @@ HELP_DICT = {
     'df_marker_file': 'match_dir df_marker_file. Not required when `--match_dir` is provided.',
     'cell_calling_method': 'Default `EmptyDrops_CR`. Choose from [`auto`, `EmptyDrops_CR`]',
     'additional_param': 'Additional parameters for the called software. Need to be enclosed in quotation marks. For example, `--{software}_param "--param1 value1 --param2 value2"`.',
-    
+    'genomeSAindexNbases': '''For small genomes, the parameter --genomeSAindexNbases must to be scaled down, with a typical 
+value of min(14, log2(GenomeLength)/2 - 1). For example, for 1 megaBase genome, this is equal 
+to 9, for 100 kiloBase genome, this is equal to 7.''',
+    'chemistry': '`--chemistry auto` can auto-detect scopeV2 mRNA, scopeV3 mRNA, full length VDJ mRNA(flv_rna) and full length VDJ(flv). You need to explicitly use `--chemistry scopeV1` for legacy chemistry scopeV1. `--chemistry customized` is used for user defined combinations that you need to provide `--pattern`, `--whitelist` and `--linker` at the same time.',   
 }
 
 # report metrics help
