@@ -4,14 +4,18 @@ from celescope.tools.multi import Multi
 
 class Multi_rna(Multi):
     """
-    Usage
+    ## Usage
     ```
         multi_rna\\
         --mapfile ./rna.mapfile\\
         --genomeDir /SGRNJ/Public/Database/genome/homo_mus\\
         --thread 8\\
+        --allowNoPolyT\\
         --mod shell
     ```
+
+    If Single nuclei RNA-Seq is used, you need to add `--gtf_type gene` to include reads mapped to 
+    intronic regions.
     """
 
 
